@@ -65,9 +65,10 @@ class VocabularyTerm(Segment):
             "Event": "A single action that occurs as a result of the user",  # noqa: E501
             "Exponentiation operator": "Multiplies a number by itself some number of times",  # noqa: E501
             "Expression": "A piece of code that produces a value",
+            "Feature": "Something a program can do",
             "Float": "A number with a decimal point",
             "Floor division operator": "Rounds the quotient down to a whole number after division",  # noqa: E501
-            "For loop": "A loop that runs a specific number of times",  # noqa: E501
+            "for loop": "A loop that runs a specific number of times",  # noqa: E501
             "Frame": "One still image within an animation, usually one iteration of a loop",  # noqa: E501
             "Function": "A named code action that can be used in a program",
             "Greater than": "Is the left value bigger than the right value?",
@@ -88,6 +89,7 @@ class VocabularyTerm(Segment):
             "Loop variable": "A variable whose value changes based on the iteration of a loop",  # noqa: E501
             "Main loop": "Keeps a window open and updated",
             "Method": "A function that belongs to an instance",
+            "Modular design": "Composing a system with independent parts",
             "Modulo operator": "Calculates the remainder after division",
             "Multiple assignment": "Assigning more than one variable with the same operator",  # noqa: E501
             "Nested conditional": "A conditional inside another conditional",
@@ -97,8 +99,10 @@ class VocabularyTerm(Segment):
             "or operator": "True if one or more parts are True",
             "Output": "Information a program gives to the user, such as text",
             "random library": "A library with code to create unpredictable values",
-            "Range": "A sequence of integers with a start and an end",
+            "range": "A sequence of integers with a start and an end",
+            "Retrospective": "A formal review of the successes and failures of recent work",  # noqa: E501
             "Return value": "Information given back by a function",
+            "Scope": "The set of work planned for a specific time period",  # noqa: E501
             "Speed": "Attributes that control how fast and what direction an instance moves on screen",  # noqa: E501
             "Sprite": "An on-screen graphic based on an image",
             "Spritesheet": "An image designed to be broken apart and used as an animation",  # noqa: E501
@@ -106,6 +110,7 @@ class VocabularyTerm(Segment):
             "Statement": "A single line of code that performs an action",
             "Start": "The first value in a range",
             "Step": "The amount that a range counts by",
+            "Stretch goal": "An optional goal which won't cause the product to fail if it's not reached",  # noqa: E501
             "String": "A group of letters, symbols and/or numbers inside double quotation marks",  # noqa: E501
             "String concatenation": "Join two strings together with the + operator",
             "String multiplication": "Repeat a string a certain number of times with the * operator",  # noqa: E501
@@ -116,6 +121,7 @@ class VocabularyTerm(Segment):
             "Typecast": "Treat one data type like another",
             "User input": "Information the program receives from the user",
             "Variable": "A storage container for information",
+            "Version": "A unique name or number for the state of a product at a particular time",  # noqa: E501
             "while loop": "Repeats a section of code until a condition is no longer True",  # noqa: E501
             "Window": "A container for displaying graphics",
         }
@@ -157,9 +163,10 @@ class VocabularyTerm(Segment):
             "Event": "3.6.1",
             "Exponentiation operator": "2.3.2",
             "Expression": "1.4.1",
+            "Feature": "2.pl3.1",
             "Float": "1.3.1",
             "Floor division operator": "2.3.2",
-            "For loop": "3.7.1",
+            "for loop": "3.7.1",
             "Frame": "3.5.1",
             "Function": "1.2.1",
             "Greater than": "2.1.2",
@@ -180,6 +187,7 @@ class VocabularyTerm(Segment):
             "Loop variable": "3.7.1",
             "Main loop": "3.4.1",
             "Method": "3.3.1",
+            "Modular design": "2.pl3.1",
             "Modulo operator": "2.3.2",
             "Multiple assignment": "3.6.2",
             "Nested conditional": "2.2.2",
@@ -189,8 +197,10 @@ class VocabularyTerm(Segment):
             "or operator": "2.4.1",
             "Output": "1.1.1",
             "random library": "2.3.1",
-            "Range": "3.7.1",
+            "range": "3.7.1",
+            "Retrospective": "2.pl3.1",
             "Return value": "1.4.2",
+            "Scope": "2.pl3.1",
             "Speed": "3.5.1",
             "Sprite": "3.4.1",
             "Spritesheet": "3.5.1",
@@ -198,6 +208,7 @@ class VocabularyTerm(Segment):
             "State": "3.6.1",
             "Start": "3.7.2",
             "Step": "3.7.2",
+            "Stretch goal": "2.pl3.1",
             "String": "1.1.1",
             "String concatenation": "1.3.2",
             "String multiplication": "1.3.2",
@@ -208,6 +219,7 @@ class VocabularyTerm(Segment):
             "Typecast": "1.3.2",
             "User input": "1.1.3",
             "Variable": "1.1.3",
+            "Version": "2.pl3.1",
             "while loop": "3.1.1",
             "Window": "3.4.1",
         }
